==> libeconf-0.5.2.tar.xz: libeconf-0.5.2/docs/libeconf_8h.js <==
var libeconf_8h =
[
    [ "econf_setValue", "libeconf_8h.html#a65b4282db33b845e3ce644ee6a2219c8", null ],
    [ "econf_free", "libeconf_8h.html#a27a9d78ae827ef885a4373fa591ded73", null ],
    [ "econf_err", "libeconf_8h.html#a48fef14efd7e0751b5794e0f307f7869", null ],
    [ "econf_file", "libeconf_8h.html#a0d29e6d5c6c6d151bb3edc54019c8735", null ],
    [ "econf_err", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0a", [
      [ "ECONF_SUCCESS", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aafe011d1ce92a3b4c1e8c172c8c3a9604", null ],
      [ "ECONF_ERROR", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaf17cead6d4a9e4bd46bf07dd14476fb2", null ],
      [ "ECONF_NOMEM", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa1d7757fbcf5df49ba92c9a436d3bff33", null ],
      [ "ECONF_NOFILE", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aad48f6a68474df566c7676ce325380b7f", null ],
      [ "ECONF_NOGROUP", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa2eb2ee8b0ffb2cd4c0829944af1168a1", null ],
      [ "ECONF_NOKEY", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aac3909d9fd9bdac53e1e8b2b80c470eb0", null ],
      [ "ECONF_EMPTYKEY", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaf3119f73c97a08fd08e2dfbc3d42493c", null ],
      [ "ECONF_WRITEERROR", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaa0542bb798322dd272fe66411b0ede6c", null ],
      [ "ECONF_PARSE_ERROR", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa6df088da6aad41d83acc2b6060acb7fe", null ],
      [ "ECONF_MISSING_BRACKET", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaaf3716ec7b6faf6a0183007060c2ac16", null ],
      [ "ECONF_MISSING_DELIMITER", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aacd662d9a8a5249d344bc716517a5506f", null ],
      [ "ECONF_EMPTY_SECTION_NAME", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa8bffb248bd0e7fbfe09f404ec73ffeb6", null ],
      [ "ECONF_TEXT_AFTER_SECTION", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa5af88d2cd68517701b2d8b9c34fbb4a0", null ]
    ] ],
    [ "econf_readFile", "libeconf_8h.html#aa03377bd02882239b3342c095f916561", null ],
    [ "econf_mergeFiles", "libeconf_8h.html#a2aba75b3474b33173edbc0f80b2e8a79", null ],
    [ "econf_readDirs", "libeconf_8h.html#a7ff92b0fb657aa21220a89a0fcb59227", null ],
    [ "econf_readDirsHistory", "libeconf_8h.html#a55faa39cd3887073d1aaba364bd09f94", null ],
    [ "econf_newKeyFile", "libeconf_8h.html#a94f42f580d8c9dff8cdb01a5c91bb5ec", null ],
    [ "econf_newIniFile", "libeconf_8h.html#a0b7c823419269683749a7394e776b22c", null ],
    [ "econf_writeFile", "libeconf_8h.html#a5f1e5a7c748ef9147fc7d16604904171", null ],
    [ "econf_getPath", "libeconf_8h.html#a74c3b496fc241cc87bd8847716fee011", null ],
    [ "econf_getGroups", "libeconf_8h.html#aa9f93a7e119c37ee3a49d1ad11936533", null ],
    [ "econf_getKeys", "libeconf_8h.html#afa58b02e97241c5e8d778f40b04731b7", null ],
    [ "econf_getIntValue", "libeconf_8h.html#acdf4785ef2a5b411fdb4f63ea5b05fbc", null ],
    [ "econf_getInt64Value", "libeconf_8h.html#a80f117888ae88f796ba8785294ee76cd", null ],
    [ "econf_getUIntValue", "libeconf_8h.html#af9ebb2c80265505d7fec80bc3ba08f06", null ],
    [ "econf_getUInt64Value", "libeconf_8h.html#a413472061e0ed9897eac190d4f3b30b2", null ],
    [ "econf_getFloatValue", "libeconf_8h.html#a56c631b316987132609b07b1e6df6e18", null ],
    [ "econf_getDoubleValue", "libeconf_8h.html#ad082e9c8bd148f6e984b6179b1c64ae9", null ],
    [ "econf_getStringValue", "libeconf_8h.html#abfe33ab2f7b5259cda5b71d488f46ab0", null ],
    [ "econf_getBoolValue", "libeconf_8h.html#a76c652840d8dfcc03de8113a7cfebc13", null ],
    [ "econf_getIntValueDef", "libeconf_8h.html#af9a74b95fd40f50b23537d1ce6ef208a", null ],
    [ "econf_getInt64ValueDef", "libeconf_8h.html#ae37f2e645f66551c3cbe337fdd5dc4ae", null ],
    [ "econf_getUIntValueDef", "libeconf_8h.html#aad4a1bd56b3aef3343b9ff529d88eee9", null ],
    [ "econf_getUInt64ValueDef", "libeconf_8h.html#a81cba085e41e786c41ccba80d48c60ca", null ],
    [ "econf_getFloatValueDef", "libeconf_8h.html#ab45fea8e2c1536c842c35a80d770ba5f", null ],
    [ "econf_getDoubleValueDef", "libeconf_8h.html#a9a684d32565f0a7ff5694f4f9cdf8a01", null ],
    [ "econf_getStringValueDef", "libeconf_8h.html#a30212473ce7ac1428a6097d6e41c9498", null ],
    [ "econf_getBoolValueDef", "libeconf_8h.html#a14c228958335cf7c2a0a04e229048a09", null ],
    [ "econf_setIntValue", "libeconf_8h.html#a9eba99cc942620012cd76d7fd487c599", null ],
    [ "econf_setInt64Value", "libeconf_8h.html#a2fe1e47b604fa259e1fd879bbdc0a347", null ],
    [ "econf_setUIntValue", "libeconf_8h.html#a43baa061fcd4f770e2d8e12d3ee58f6e", null ],
    [ "econf_setUInt64Value", "libeconf_8h.html#a0e4050978c3ed94332f8e82862fa4b62", null ],
    [ "econf_setFloatValue", "libeconf_8h.html#a836b5196842a134fc370c7bc24ffefcb", null ],
    [ "econf_setDoubleValue", "libeconf_8h.html#a1ba57afda092a5a591f3cbc14a00caf6", null ],
    [ "econf_setStringValue", "libeconf_8h.html#a808d966041916c3de263a79a6b4983c5", null ],
    [ "econf_setBoolValue", "libeconf_8h.html#a3f873713848631a5ded240479af96de4", null ],
    [ "econf_errString", "libeconf_8h.html#aad9997fe22b287d5b943e2846abe9e32", null ],
    [ "econf_errLocation", "libeconf_8h.html#adc459d1dfa9096425d4f248b04669761", null ],
    [ "econf_freeArray", "libeconf_8h.html#ad6da8744e42ba1f4ddf5179a79fde50e", null ],
    [ "econf_freeFile", "libeconf_8h.html#af5fe145fe20e3a39efa781756a1f2589", null ]
];

==> libeconf-0.6.1.tar.xz: libeconf-0.6.1/docs/libeconf_8h.js <==
var libeconf_8h =
[
    [ "econf_setValue", "libeconf_8h.html#a65b4282db33b845e3ce644ee6a2219c8", null ],
    [ "econf_free", "libeconf_8h.html#a27a9d78ae827ef885a4373fa591ded73", null ],
    [ "econf_err", "libeconf_8h.html#a48fef14efd7e0751b5794e0f307f7869", null ],
    [ "econf_file", "libeconf_8h.html#a0d29e6d5c6c6d151bb3edc54019c8735", null ],
    [ "econf_err", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0a", [
      [ "ECONF_SUCCESS", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aafe011d1ce92a3b4c1e8c172c8c3a9604", null ],
      [ "ECONF_ERROR", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaf17cead6d4a9e4bd46bf07dd14476fb2", null ],
      [ "ECONF_NOMEM", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa1d7757fbcf5df49ba92c9a436d3bff33", null ],
      [ "ECONF_NOFILE", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aad48f6a68474df566c7676ce325380b7f", null ],
      [ "ECONF_NOGROUP", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa2eb2ee8b0ffb2cd4c0829944af1168a1", null ],
      [ "ECONF_NOKEY", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aac3909d9fd9bdac53e1e8b2b80c470eb0", null ],
      [ "ECONF_EMPTYKEY", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaf3119f73c97a08fd08e2dfbc3d42493c", null ],
      [ "ECONF_WRITEERROR", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaa0542bb798322dd272fe66411b0ede6c", null ],
      [ "ECONF_PARSE_ERROR", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa6df088da6aad41d83acc2b6060acb7fe", null ],
      [ "ECONF_MISSING_BRACKET", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaaf3716ec7b6faf6a0183007060c2ac16", null ],
      [ "ECONF_MISSING_DELIMITER", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aacd662d9a8a5249d344bc716517a5506f", null ],
      [ "ECONF_EMPTY_SECTION_NAME", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa8bffb248bd0e7fbfe09f404ec73ffeb6", null ],
      [ "ECONF_TEXT_AFTER_SECTION", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa5af88d2cd68517701b2d8b9c34fbb4a0", null ],
      [ "ECONF_FILE_LIST_IS_NULL", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa1635184e73c0a6d522d82bba0abd0e4a", null ],
      [ "ECONF_WRONG_BOOLEAN_VALUE", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa4725ff7773c2b5a9d703460f1ca070f4", null ],
      [ "ECONF_KEY_HAS_NULL_VALUE", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aaa7f3b09e2b8a627f11f4df6e745103c9", null ],
      [ "ECONF_WRONG_OWNER", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aae8f9a6e81d529822968f1af70c9b1946", null ],
      [ "ECONF_WRONG_GROUP", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aab28f4a0d53a21a1f0ed21fe8601a6d14", null ],
      [ "ECONF_WRONG_FILE_PERMISSION", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa768ba4de0c5ba47154dba9dc4a26cb84", null ],
      [ "ECONF_WRONG_DIR_PERMISSION", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aac04246deccfe0075cc58956c543fa408", null ],
      [ "ECONF_ERROR_FILE_IS_SYM_LINK", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aab09de6a0a65f054a6c542151a675e241", null ],
      [ "ECONF_PARSING_CALLBACK_FAILED", "libeconf_8h.html#a30cb4e6c5ce4daa333646b23b20caa0aa6b9c2f2cdbbf94dbaabfa42e3425deb4", null ]
    ] ],
    [ "econf_readFile", "libeconf_8h.html#aa03377bd02882239b3342c095f916561", null ],
    [ "econf_readFileWithCallback", "libeconf_8h.html#a6bf61969ee7ea191fdd28b0c8de5761d", null ],
    [ "econf_mergeFiles", "libeconf_8h.html#a2aba75b3474b33173edbc0f80b2e8a79", null ],
    [ "econf_readDirs", "libeconf_8h.html#a7ff92b0fb657aa21220a89a0fcb59227", null ],
    [ "econf_readDirsWithCallback", "libeconf_8h.html#aa54f0d5e7d918e23ae53f66c48191811", null ],
    [ "econf_readDirsHistory", "libeconf_8h.html#a55faa39cd3887073d1aaba364bd09f94", null ],
    [ "econf_readDirsHistoryWithCallback", "libeconf_8h.html#a50cb704ad90f36ade8a619bfc986f89b", null ],
    [ "econf_newKeyFile", "libeconf_8h.html#a94f42f580d8c9dff8cdb01a5c91bb5ec", null ],
    [ "econf_newIniFile", "libeconf_8h.html#a0b7c823419269683749a7394e776b22c", null ],
    [ "econf_comment_tag", "libeconf_8h.html#a5d24ab3c1515a2a0cf4668221a0ee6f7", null ],
    [ "econf_delimiter_tag", "libeconf_8h.html#a2fa45814606cac4dc4abdfe462f8ee70", null ],
    [ "econf_set_comment_tag", "libeconf_8h.html#a1dc59b13a0293943b10dfc09e6daba09", null ],
    [ "econf_set_delimiter_tag", "libeconf_8h.html#aa14d17dc8e3ebc26e155ceb2d497ad14", null ],
    [ "econf_writeFile", "libeconf_8h.html#a5f1e5a7c748ef9147fc7d16604904171", null ],
    [ "econf_getPath", "libeconf_8h.html#a74c3b496fc241cc87bd8847716fee011", null ],
    [ "econf_getGroups", "libeconf_8h.html#aa9f93a7e119c37ee3a49d1ad11936533", null ],
    [ "econf_getKeys", "libeconf_8h.html#afa58b02e97241c5e8d778f40b04731b7", null ],
    [ "econf_getIntValue", "libeconf_8h.html#acdf4785ef2a5b411fdb4f63ea5b05fbc", null ],
    [ "econf_getInt64Value", "libeconf_8h.html#a80f117888ae88f796ba8785294ee76cd", null ],
    [ "econf_getUIntValue", "libeconf_8h.html#af9ebb2c80265505d7fec80bc3ba08f06", null ],
    [ "econf_getUInt64Value", "libeconf_8h.html#a413472061e0ed9897eac190d4f3b30b2", null ],
    [ "econf_getFloatValue", "libeconf_8h.html#a56c631b316987132609b07b1e6df6e18", null ],
    [ "econf_getDoubleValue", "libeconf_8h.html#ad082e9c8bd148f6e984b6179b1c64ae9", null ],
    [ "econf_getStringValue", "libeconf_8h.html#abfe33ab2f7b5259cda5b71d488f46ab0", null ],
    [ "econf_getBoolValue", "libeconf_8h.html#a76c652840d8dfcc03de8113a7cfebc13", null ],
    [ "econf_getIntValueDef", "libeconf_8h.html#af9a74b95fd40f50b23537d1ce6ef208a", null ],
    [ "econf_getInt64ValueDef", "libeconf_8h.html#ae37f2e645f66551c3cbe337fdd5dc4ae", null ],
    [ "econf_getUIntValueDef", "libeconf_8h.html#aad4a1bd56b3aef3343b9ff529d88eee9", null ],
    [ "econf_getUInt64ValueDef", "libeconf_8h.html#a81cba085e41e786c41ccba80d48c60ca", null ],
    [ "econf_getFloatValueDef", "libeconf_8h.html#ab45fea8e2c1536c842c35a80d770ba5f", null ],
    [ "econf_getDoubleValueDef", "libeconf_8h.html#a9a684d32565f0a7ff5694f4f9cdf8a01", null ],
    [ "econf_getStringValueDef", "libeconf_8h.html#a30212473ce7ac1428a6097d6e41c9498", null ],
    [ "econf_getBoolValueDef", "libeconf_8h.html#a14c228958335cf7c2a0a04e229048a09", null ],
    [ "econf_setIntValue", "libeconf_8h.html#a9eba99cc942620012cd76d7fd487c599", null ],
    [ "econf_setInt64Value", "libeconf_8h.html#a2fe1e47b604fa259e1fd879bbdc0a347", null ],
    [ "econf_setUIntValue", "libeconf_8h.html#a43baa061fcd4f770e2d8e12d3ee58f6e", null ],
    [ "econf_setUInt64Value", "libeconf_8h.html#a0e4050978c3ed94332f8e82862fa4b62", null ],
    [ "econf_setFloatValue", "libeconf_8h.html#a836b5196842a134fc370c7bc24ffefcb", null ],
    [ "econf_setDoubleValue", "libeconf_8h.html#a1ba57afda092a5a591f3cbc14a00caf6", null ],
    [ "econf_setStringValue", "libeconf_8h.html#a808d966041916c3de263a79a6b4983c5", null ],
    [ "econf_setBoolValue", "libeconf_8h.html#a3f873713848631a5ded240479af96de4", null ],
    [ "econf_errString", "libeconf_8h.html#aad9997fe22b287d5b943e2846abe9e32", null ],
    [ "econf_errLocation", "libeconf_8h.html#adc459d1dfa9096425d4f248b04669761", null ],
    [ "econf_freeArray", "libeconf_8h.html#ad6da8744e42ba1f4ddf5179a79fde50e", null ],
    [ "econf_freeFile", "libeconf_8h.html#af5fe145fe20e3a39efa781756a1f2589", null ],
    [ "__attribute__", "libeconf_8h.html#a75b8fd4dfcc61b88e96db56be871143a", null ],
    [ "econf_set_conf_dirs", "libeconf_8h.html#a0466a16c30cfcd58ec6201d210c64731", null ],
    [ "dir_perms", "libeconf_8h.html#a8180855e033a12c0de69b680c99af657", null ]
];
